# Generated by roxygen2: do not edit by hand

S3method(coef,gctsc)
S3method(plot,gctsc)
S3method(predict,gctsc)
S3method(print,gctsc)
S3method(print,summary.gctsc)
S3method(residuals,gctsc)
S3method(summary,gctsc)
export(arma.cormat)
export(bbinom.marg)
export(binom.marg)
export(gctsc)
export(gctsc.opts)
export(negbin.marg)
export(pmvn)
export(pmvt)
export(poisson.marg)
export(sim_bbinom)
export(sim_binom)
export(sim_negbin)
export(sim_poisson)
export(sim_zib)
export(sim_zibb)
export(sim_zip)
export(zib.marg)
export(zibb.marg)
export(zip.marg)
importFrom(Rcpp,evalCpp)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,dev.interactive)
importFrom(graphics,abline)
importFrom(graphics,frame)
importFrom(graphics,hist)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(stats,acf)
importFrom(stats,arima)
importFrom(stats,arima.sim)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,dbinom)
importFrom(stats,delete.response)
importFrom(stats,dnbinom)
importFrom(stats,dpois)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,pacf)
importFrom(stats,pbinom)
importFrom(stats,plogis)
importFrom(stats,pnbinom)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,ppoints)
importFrom(stats,ppois)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,qbinom)
importFrom(stats,qlogis)
importFrom(stats,qnbinom)
importFrom(stats,qnorm)
importFrom(stats,qpois)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,quasibinomial)
importFrom(stats,rchisq)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,toeplitz)
importFrom(utils,data)
importFrom(utils,tail)
useDynLib(gctsc, .registration = TRUE)
